@@ -19,7 +19,7 @@ from peyecoder.panels import Prescreen, Code, LogTable
 from peyecoder.models import Subject
 from peyecoder.file_utils import load_datafile, save_datafile
 from peyecoder.dialogs import SubjectDialog, TimecodeDialog, OccluderDialog, SettingsDialog, CodeComparisonDialog, \
-    ReportDialog, ExportDialog, get_save_filename
+    ReportDialog, ExportDialog, get_save_filename, ReplaceDialog
 from peyecoder.reliability import reliability_report
 from peyecoder import version
 
@@ -60,6 +60,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.settings_dialog = None
         self.code_comparison_dialog = None
         self.report_dialog = None
+        self.replace_dialog = None
 
         self.subject = Subject(self)
 
@@ -180,6 +181,10 @@ class MainWindow(QtWidgets.QMainWindow):
         self.settings_dialog = None
         self.code_comparison_dialog = None
 
+        # reset coding controls
+        self.prescreen_tab.trial_box.setValue(1)
+        self.code_tab.trial_box.setValue(1)
+
         self.update_log()
         self.reset_info_panel()
 
@@ -318,6 +323,12 @@ class MainWindow(QtWidgets.QMainWindow):
         if self.active_tab == TAB_PRESCREEN:
             self.logtable.set_prescreen_labels(self.prescreen_tab.prescreener())
             self.logtable.load_data(self.subject.reasons.render(self.prescreen_tab.prescreener()))
+            error_rows, error_trials = self.subject.reasons.error_items(self.prescreen_tab.prescreener())
+            self.logtable.redden_rows(error_rows)
+            if error_trials:
+                self.message_box.setText('Mismatch between prescreener 1 and prescreener 2 for trials {}'.format(error_trials))
+            else:
+                self.message_box.setText('')
         elif self.active_tab == TAB_CODE:
             self.logtable.set_code_labels()
             self.logtable.load_data(self.subject.events.render(self.subject.timecode_offsets, self.timecode))
@@ -438,6 +449,14 @@ class MainWindow(QtWidgets.QMainWindow):
         decrement_action.setShortcut('-')
         decrement_action.setShortcutContext(Qt.WidgetShortcut)
 
+        increment_selected_action = QAction('Increment Selected Trials', self)
+        increment_selected_action.setShortcut('Alt++')
+        increment_selected_action.setShortcutContext(Qt.WidgetShortcut)
+
+        decrement_selected_action = QAction('Decrement Selected Trials', self)
+        decrement_selected_action.setShortcut('Alt+-')
+        decrement_selected_action.setShortcutContext(Qt.WidgetShortcut)
+
         help_url_action = QAction('Online Help', self)
         help_url_action.triggered.connect(self.open_help_url)
 
@@ -446,6 +465,7 @@ class MainWindow(QtWidgets.QMainWindow):
         about_box_action.triggered.connect(self.show_about_box)
 
         export_action = QAction('E&xport CSV', self)
+        export_action.setShortcut('Ctrl+e')
         export_action.setStatusTip('Export CSV')
         export_action.triggered.connect(self.export_csv)
 
@@ -468,14 +488,20 @@ class MainWindow(QtWidgets.QMainWindow):
         self.open_subject_action.triggered.connect(self.open_subject_dialog)
 
         self.open_occluders_action = QAction('&Occluders', self)
+        self.open_occluders_action.setShortcut('Ctrl+b')
         self.open_occluders_action.setStatusTip('Open Occluder Window')
         self.open_occluders_action.triggered.connect(self.open_occluder_dialog)
 
         self.open_settings_action = QAction('&Settings', self)
+        self.open_settings_action.setShortcut('Ctrl+,')
         self.open_settings_action.setStatusTip('Open Settings Window')
         self.open_settings_action.setMenuRole(QAction.NoRole)
         self.open_settings_action.triggered.connect(self.open_settings_dialog)
 
+        self.open_replace_action = QAction('&Replace Responses', self)
+        self.open_replace_action.setStatusTip('Find/Replace Responses')
+        self.open_replace_action.triggered.connect(self.open_replace_dialog)
+
         # Create menu bar and add action
         menu_bar = self.menuBar()
         file_menu = menu_bar.addMenu('&File')
@@ -494,6 +520,7 @@ class MainWindow(QtWidgets.QMainWindow):
         edit_menu.addAction(self.open_subject_action)
         edit_menu.addAction(self.open_occluders_action)
         edit_menu.addAction(self.open_settings_action)
+        edit_menu.addAction(self.open_replace_action)
 
         controls_menu = menu_bar.addMenu('&Controls')
         controls_menu.addAction(prescreen_action)
@@ -506,6 +533,8 @@ class MainWindow(QtWidgets.QMainWindow):
         controls_menu.addSeparator()
         controls_menu.addAction(increment_action)
         controls_menu.addAction(decrement_action)
+        controls_menu.addAction(increment_selected_action)
+        controls_menu.addAction(decrement_selected_action)
 
         help_menu = menu_bar.addMenu('&Help')
         help_menu.addAction(help_url_action)
@@ -558,13 +587,15 @@ class MainWindow(QtWidgets.QMainWindow):
         elif e.key() == Qt.Key_Space:
             self.toggle_state()
         elif e.key() in (Qt.Key_Plus, Qt.Key_Equal):
-            if self.logtable.has_selection():
-                self.change_selected_trials(1)
+            if e.modifiers() & Qt.AltModifier:
+                if self.logtable.has_selection():
+                    self.change_selected_trials(1)
             else:
                 self.change_trial(1)
         elif e.key() == Qt.Key_Minus:
-            if self.logtable.has_selection():
-                self.change_selected_trials(-1)
+            if e.modifiers() & Qt.AltModifier:
+                if self.logtable.has_selection():
+                    self.change_selected_trials(-1)
             else:
                 self.change_trial(-1)
         elif e.key() in (Qt.Key_Enter, Qt.Key_Return):
@@ -575,9 +606,15 @@ class MainWindow(QtWidgets.QMainWindow):
         elif e.key() in (Qt.Key_Delete, Qt.Key_Backspace):
             # The order of operations is important here
             selected_rows = self.logtable.selected_rows()
+            next_row = max(selected_rows) - len(selected_rows) + 1  # identify the row after the last row to be deleted
             self.logtable.delete_selected()
             self.delete_data_rows(selected_rows)
             self.update_log()  # necessary only to update row highlighting if error status has changed
+
+            # Disconnect self.select_code_row before highlighting next row -- don't want to change position in video
+            self.logtable.itemSelectionChanged.disconnect(self.select_code_row)
+            self.logtable.select_rows([next_row])  # highlight the row after the last deleted row
+            self.logtable.itemSelectionChanged.connect(self.select_code_row)
             self.update_info_panel()
         elif e.key() == self.subject.settings.get('Toggle Trial Status Key', None):
             # toggle between 0 and 1
@@ -605,7 +642,7 @@ class MainWindow(QtWidgets.QMainWindow):
         elif self.active_tab == TAB_CODE:
             for r in rows:
                 self.subject.events.change_trial(r, delta)
-        self.update_log()
+        self.update_log(preserve_highlight=True)
         self.update_info_panel()
 
     def change_trial(self, delta):
@@ -629,6 +666,11 @@ class MainWindow(QtWidgets.QMainWindow):
             self.settings_dialog = SettingsDialog(self)
         self.settings_dialog.show()
 
+    def open_replace_dialog(self):
+        if not self.replace_dialog:
+            self.replace_dialog = ReplaceDialog(self)
+        self.replace_dialog.show()
+
     def enable_controls(self):
         self.play_button.setEnabled(True)
         self.next_button.setEnabled(True)
@@ -871,7 +913,10 @@ class MainWindow(QtWidgets.QMainWindow):
         except:
             QMessageBox.warning(self, 'peyecoder', ('Unable to seek to the requested position in the audio.'
                                                     ' This likely means that an incorrect timecode was entered '
-                                                    'when the video was opened.'), QMessageBox.Ok)
+                                                    'when the video was opened.  Reload video and enter correct '
+                                                    'starting timestamp.'), QMessageBox.Ok)
+            self.subject.events.reset_offset()
+
         self.update_timecode()
         self.show_frame()
 
