@@ -212,13 +212,34 @@ class Reasons:
                 data.append([t, p1.include, p1.reason, p2.include, p2.reason])
         return data
 
+    def error_items(self, ps=0):
+        """Check for discrepencies between prescreener 1 and prescreener 2, and return a list of row numbers
+        for rows that should be highlighted.  No need for error messages.
+        :param ps: Prescreener number (1 or 2) or 0 (default) for both
+        """
+        assert ps in (0, 1, 2)
+
+        error_rows = []
+        error_trials = []
+        if all(self.ps):  # Entries exist for both prescreeners
+            trials = list(set(self.ps[0]).union(self.ps[1]))
+            for i, t in enumerate(trials):
+                p1 = self.ps[0].get(t, Reason(t, None, ''))
+                p2 = self.ps[1].get(t, Reason(t, None, ''))
+                if p1.include != p2.include or p1.reason != p2.reason:
+                    error_rows.append(i)
+                    error_trials.append(t)
+        if ps in (1, 2):
+            error_rows = [i for i, t in enumerate(self.ps[ps - 1]) if t in error_trials]
+        return error_rows, error_trials
+
     def unused(self):
         """List of trials prescreened out by prescreener 1"""
         return [v.trial for v in self.ps[0].values() if not v._include]
 
     def unused_reasons(self):
-        """Dictionary linking trials to reasons for exclusion"""
-        return {v.trial: v.reason for v in self.ps[0].values() if not v._include}
+        """Dictionary linking trials to reasons for screening"""
+        return {v.trial: v.reason for v in self.ps[0].values()}
 
     def get_unused_display(self):
         return ', '.join([str(s) for s in self.unused()])
@@ -326,6 +347,7 @@ class EventsA:
 class Events:
     def __init__(self, events=None):
         self.events = SortedList(events)
+        self.removed_offset = 0
 
     def add_event(self, event):
         self.events.add(event)
@@ -391,11 +413,19 @@ class Events:
 
     def remove_offset(self, offset):
         """Remove offset from any events having has_offset == True"""
+        self.removed_offset = offset  # to allow undo
         for event in self.events:
             if event.has_offset:
                 event.frame -= offset
                 event.has_offset = False
 
+    def reset_offset(self):
+        """Mark events as having offset to allow recovery from state where the initial timecode was entered incorrectly"""
+        for event in self.events:
+            event.has_offset = True
+            event.frame += self.removed_offset
+        self.removed_offset = 0
+
     def error_items(self, unused_trials, max_trial):
         """ Check for errors and return a list of row numbers (which should be highlighted) and
         corresponding error messages"""
@@ -547,11 +577,22 @@ class Trial(dict):
     """Subclass of dict used to represent a row of the TrialOrder table"""
     def inverted_target(self):
         """Swap left and right target side to account for difference between participant and camera perspective"""
+        subs = {'Right': 'Left', 'Left': 'Right',
+                'right': 'left', 'left': 'right',
+                'RIGHT': 'LEFT', 'LEFT': 'RIGHT'}
+
         try:
+            # Standard coding
             if self['Target Side'] in ('R', 'L'):
                 return {'R': 'L', 'L': 'R'}[self['Target Side']]
-            else:
-                return self['Target Side']
+
+            # Nonstandard coding
+            for key in subs.keys():
+                if key in self['Target Side']:
+                    return self['Target Side'].replace(key, subs[key])
+
+            # Not invertible
+            return self['Target Side']
         except KeyError:
             return 'No target to invert'
 
@@ -586,7 +627,7 @@ class TrialOrder:
         return ', '.join([str(s) for s in self.unused])
 
     def calc_unused(self):
-        self.unused = [d['Trial Number'] for d in self.data if d['Used'] == 'no']
+        self.unused = [d['Trial Number'] for d in self.data if d['Used'].lower() == 'no']
 
     def calc_max_trial(self):
         """Determine the highest-numbered trial in the trial order"""
