@@ -15,7 +15,7 @@ class Prescreen(QWidget):
         'Child Talking',
         'Parent Talking',
         'Parent Interference',
-        'Child Not Looking Before Sound Offset',
+        'Child Not Looking Before Sound',
         'Equipment Malfunction',
         'Experiment Ended Early',
         'Other'
@@ -179,6 +179,7 @@ class LogTable(QTableWidget):
         """ Append an entry to the table data and to the table"""
         self.data.append(entry)
         self._add_row(entry)
+        self.repaint()
 
     def _add_row(self, entry):
         # Add a row to the table, given an iterable
@@ -213,6 +214,7 @@ class LogTable(QTableWidget):
                 self.data.pop(row)
                 self.removeRow(row)
                 deleted_rows.append(row)
+        self.repaint()
         return deleted_rows
 
     def increment_selected(self):
@@ -243,15 +245,10 @@ class LogTable(QTableWidget):
 
     def select_rows(self, rows):
         """Select rows in the table specified as keys in a dictionary"""
-        first = True
-        firstrow = 0
         for r in rows:
-            if first:
-                firstrow = r
             for c in range(self.columnCount()):
-                self.item(r, c).setSelected(True)
-
-        self.setCurrentIndex(self.indexFromItem(self.item(firstrow, 0)))
+                if self.item(r, c):
+                    self.item(r, c).setSelected(True)
 
     def set_code_labels(self):
         self.set_labels(self.Labels.Code)
